@@ -7,10 +7,10 @@
 # the same terms as the Perl 5 programming language system itself.
 #
 package AnyEvent::Riak;
-$AnyEvent::Riak::VERSION = '0.92';
+$AnyEvent::Riak::VERSION = '0.93';
 # ABSTRACT: AnyEvent ProtocolBuffers Riak Client
 
-use 5.012;
+use 5.010;
 use strict;
 use warnings;
 use AnyEvent::Riak::PBC;
@@ -185,10 +185,10 @@ sub _run_cmd {
 
     $handle->push_read( chunk => 4, sub {
          my $len = unpack "N", $_[1];
-         $handle->timeout_reset;
+         $_[0]->timeout_reset;
          $_[0]->unshift_read( chunk => $len, sub {
-             $handle->timeout_reset;
-             $handle->timeout(0);
+             $_[0]->timeout_reset;
+             $_[0]->timeout(0);
              my ( $response_code, $response_body ) = unpack( 'c a*', $_[1] );
 
              if ($response_code == $message_codes->{RpbErrorResp}) {
@@ -279,7 +279,7 @@ AnyEvent::Riak - AnyEvent ProtocolBuffers Riak Client
 
 =head1 VERSION
 
-version 0.92
+version 0.93
 
 =head1 SYNOPSIS
 
